@@ -277,6 +277,7 @@ correct_prefix (gchar **path)
   if (strncmp (*path, GTK_PREFIX "/", strlen (GTK_PREFIX "/")) == 0 ||
       strncmp (*path, GTK_PREFIX "\\", strlen (GTK_PREFIX "\\")) == 0)
     {
+	  gchar *tem = NULL;
       if (strlen(*path) > 5 && strncmp (*path - 5, ".libs", 5) == 0)
         {
           /* We are being run from inside the build tree, and shouldn't mess about. */
@@ -290,7 +291,7 @@ correct_prefix (gchar **path)
        * builder's machine. Replace the build-time prefix with the
        * installation prefix on this machine.
        */
-      gchar *tem = *path;
+      tem = *path;
       *path = g_strconcat (get_toplevel (), tem + strlen (GTK_PREFIX), NULL);
       g_free (tem);
     }
@@ -395,6 +396,9 @@ gdk_pixbuf_io_init (void)
 #ifdef INCLUDE_jasper
 	load_one_builtin_module (jasper);
 #endif
+#ifdef INCLUDE_qtif
+	load_one_builtin_module (qtif);
+#endif
 #ifdef INCLUDE_gdiplus
 	/* We don't bother having the GDI+ loaders individually selectable
 	 * for building in or not.
@@ -588,6 +592,7 @@ module (tga);
 module (pcx);
 module (icns);
 module (jasper);
+module (qtif);
 module (gdip_ico);
 module (gdip_wmf);
 module (gdip_emf);
@@ -666,6 +671,9 @@ gdk_pixbuf_load_module_unlocked (GdkPixbufModule *image_module,
 #ifdef INCLUDE_jasper
 	try_module (jasper,jasper);
 #endif
+#ifdef INCLUDE_qtif
+	try_module (qtif,qtif);
+#endif
 #ifdef INCLUDE_gdiplus
 	try_module (ico,gdip_ico);
 	try_module (wmf,gdip_wmf);
@@ -1853,7 +1861,7 @@ gdk_pixbuf_real_save_to_callback (GdkPixbuf         *pixbuf,
  * @pixbuf: a #GdkPixbuf.
  * @filename: name of file to save.
  * @type: name of file format.
- * @error: return location for error, or %NULL
+ * @error: (allow-none): return location for error, or %NULL
  * @Varargs: list of key-value save options
  *
  * Saves pixbuf to a file in format @type. By default, "jpeg", "png", "ico" 
@@ -1894,6 +1902,25 @@ gdk_pixbuf_real_save_to_callback (GdkPixbuf         *pixbuf,
  * be specified using the "compression" parameter; it's value is in an
  * integer in the range of [0,9].
  *
+ * ICC color profiles can also be embedded into PNG and TIFF images.
+ * The "icc-profile" value should be the complete ICC profile encoded
+ * into base64.
+ *
+ * <informalexample><programlisting>
+ * gchar *contents;
+ * gchar *contents_encode;
+ * gsize length;
+ * g_file_get_contents ("/home/hughsie/.color/icc/L225W.icm", &contents, &length, NULL);
+ * contents_encode = g_base64_encode ((const guchar *) contents, length);
+ * gdk_pixbuf_save (pixbuf, handle, "png", &amp;error,
+ *                  "icc-profile", contents_encode,
+ *                  NULL);
+ * </programlisting></informalexample>
+ *
+ * TIFF images recognize a "compression" option which acceps an integer value.
+ * Among the codecs are 1 None, 2 Huffman, 5 LZW, 7 JPEG and 8 Deflate, see
+ * the libtiff documentation and tiff.h for all supported codec values.
+ *
  * ICO images can be saved in depth 16, 24, or 32, by using the "depth"
  * parameter. When the ICO saver is given "x_hot" and "y_hot" parameters,
  * it produces a CUR instead of an ICO.
@@ -1982,7 +2009,7 @@ gdk_pixbuf_save (GdkPixbuf  *pixbuf,
  * @type: name of file format.
  * @option_keys: name of options to set, %NULL-terminated
  * @option_values: values for named options
- * @error: return location for error, or %NULL
+ * @error: (allow-none): return location for error, or %NULL
  *
  * Saves pixbuf to a file in @type, which is currently "jpeg", "png", "tiff", "ico" or "bmp".
  * If @error is set, %FALSE will be returned. 
@@ -2030,6 +2057,7 @@ gdk_pixbuf_savev (GdkPixbuf  *pixbuf,
        if (!result) {
                g_return_val_if_fail (error == NULL || *error != NULL, FALSE);
                fclose (f);
+               g_unlink (filename);
                return FALSE;
        }
 
@@ -2088,7 +2116,7 @@ gdk_pixbuf_savev (GdkPixbuf  *pixbuf,
  *   the save routine generates.
  * @user_data: user data to pass to the save function.
  * @type: name of file format.
- * @error: return location for error, or %NULL
+ * @error: (allow-none): return location for error, or %NULL
  * @Varargs: list of key-value save options
  *
  * Saves pixbuf in format @type by feeding the produced data to a 
@@ -2144,7 +2172,7 @@ gdk_pixbuf_save_to_callback    (GdkPixbuf  *pixbuf,
  * @type: name of file format.
  * @option_keys: name of options to set, %NULL-terminated
  * @option_values: values for named options
- * @error: return location for error, or %NULL
+ * @error: (allow-none): return location for error, or %NULL
  *
  * Saves pixbuf to a callback in format @type, which is currently "jpeg",
  * "png", "tiff", "ico" or "bmp".  If @error is set, %FALSE will be returned. See
@@ -2189,7 +2217,7 @@ gdk_pixbuf_save_to_callbackv   (GdkPixbuf  *pixbuf,
  * @buffer: location to receive a pointer to the new buffer.
  * @buffer_size: location to receive the size of the new buffer.
  * @type: name of file format.
- * @error: return location for error, or %NULL
+ * @error: (allow-none): return location for error, or %NULL
  * @Varargs: list of key-value save options
  *
  * Saves pixbuf to a new buffer in format @type, which is currently "jpeg",
@@ -2278,7 +2306,7 @@ save_to_buffer_callback (const gchar *data,
  * @type: name of file format.
  * @option_keys: name of options to set, %NULL-terminated
  * @option_values: values for named options
- * @error: return location for error, or %NULL
+ * @error: (allow-none): return location for error, or %NULL
  *
  * Saves pixbuf to a new buffer in format @type, which is currently "jpeg",
  * "tiff", "png", "ico" or "bmp".  See gdk_pixbuf_save_to_buffer() 
@@ -2374,7 +2402,7 @@ save_to_stream (const gchar  *buffer,
  * @stream: a #GOutputStream to save the pixbuf to
  * @type: name of file format
  * @cancellable: optional #GCancellable object, %NULL to ignore
- * @error: return location for error, or %NULL
+ * @error: (allow-none): return location for error, or %NULL
  * @Varargs: list of key-value save options
  *
  * Saves @pixbuf to an output stream.
