@@ -268,30 +268,16 @@ gtk_cell_renderer_combo_set_property (GObject      *object,
     {
     case PROP_MODEL:
       {
-	GObject *object;
         GtkCellRendererComboPrivate *priv;
 
         priv = GTK_CELL_RENDERER_COMBO_GET_PRIVATE (cell);
 
-	if (cell->model)
-	  {
-            if (priv->combo)
-              gtk_combo_box_set_model (GTK_COMBO_BOX (priv->combo), NULL);
-	    g_object_unref (cell->model);
-	    cell->model = NULL;
-	  }
-
-	object = g_value_get_object (value);
-        if (object)
-          {
-            g_return_if_fail (GTK_IS_TREE_MODEL (object));
-            g_object_ref (object);
-
-            cell->model = GTK_TREE_MODEL (object);
-            if (priv->combo)
-              gtk_combo_box_set_model (GTK_COMBO_BOX (priv->combo), cell->model);
-          }
-	break;
+        if (cell->model)
+          g_object_unref (cell->model);
+        cell->model = GTK_TREE_MODEL (g_value_get_object (value));
+        if (cell->model)
+          g_object_ref (cell->model);
+        break;
       }
     case PROP_TEXT_COLUMN:
       cell->text_column = g_value_get_int (value);
@@ -345,8 +331,10 @@ gtk_cell_renderer_combo_editing_done (GtkCellEditable *combo,
       g_signal_handler_disconnect (combo, cell->focus_out_id);
       cell->focus_out_id = 0;
     }
-  
-  canceled = _gtk_combo_box_editing_canceled (GTK_COMBO_BOX (combo));
+
+  g_object_get (combo,
+                "editing-canceled", &canceled,
+                NULL);
   gtk_cell_renderer_stop_editing (GTK_CELL_RENDERER (data), canceled);
   if (canceled)
     {
