@@ -17,6 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_COMBO_BOX_ENTRY_H__
 #define __GTK_COMBO_BOX_ENTRY_H__
 
@@ -41,7 +45,7 @@ struct _GtkComboBoxEntry
   GtkComboBox parent_instance;
 
   /*< private >*/
-  GtkComboBoxEntryPrivate *priv;
+  GtkComboBoxEntryPrivate *GSEAL (priv);
 };
 
 struct _GtkComboBoxEntryClass
