@@ -1519,7 +1519,7 @@ gtk_main_do_event (GdkEvent *event)
        *  then we send the event to the original event widget.
        *  This is the key to implementing modality.
        */
-      if (GTK_WIDGET_IS_SENSITIVE (event_widget) &&
+      if (gtk_widget_is_sensitive (event_widget) &&
 	  gtk_widget_is_ancestor (event_widget, grab_widget))
 	grab_widget = event_widget;
     }
@@ -1559,14 +1559,14 @@ gtk_main_do_event (GdkEvent *event)
 	{
 	  g_object_ref (event_widget);
 	  if (!gtk_widget_event (event_widget, event) &&
-	      GTK_WIDGET_REALIZED (event_widget))
+	      gtk_widget_get_realized (event_widget))
 	    gtk_widget_destroy (event_widget);
 	  g_object_unref (event_widget);
 	}
       break;
       
     case GDK_EXPOSE:
-      if (event->any.window && GTK_WIDGET_DOUBLE_BUFFERED (event_widget))
+      if (event->any.window && gtk_widget_get_double_buffered (event_widget))
 	{
 	  gdk_window_begin_paint_region (event->any.window, event->expose.region);
 	  gtk_widget_send_expose (event_widget, event);
@@ -1650,13 +1650,13 @@ gtk_main_do_event (GdkEvent *event)
     case GDK_ENTER_NOTIFY:
       GTK_PRIVATE_SET_FLAG (event_widget, GTK_HAS_POINTER);
       _gtk_widget_set_pointer_window (event_widget, event->any.window);
-      if (GTK_WIDGET_IS_SENSITIVE (grab_widget))
+      if (gtk_widget_is_sensitive (grab_widget))
 	gtk_widget_event (grab_widget, event);
       break;
       
     case GDK_LEAVE_NOTIFY:
       GTK_PRIVATE_UNSET_FLAG (event_widget, GTK_HAS_POINTER);
-      if (GTK_WIDGET_IS_SENSITIVE (grab_widget))
+      if (gtk_widget_is_sensitive (grab_widget))
 	gtk_widget_event (grab_widget, event);
       break;
       
@@ -1759,7 +1759,7 @@ gtk_grab_notify_foreach (GtkWidget *child,
     {
       GTK_PRIVATE_SET_FLAG (child, GTK_SHADOWED);
       if (!was_shadowed && GTK_WIDGET_HAS_POINTER (child)
-	  && GTK_WIDGET_IS_SENSITIVE (child))
+	  && gtk_widget_is_sensitive (child))
 	_gtk_widget_synthesize_crossing (child, info->new_grab_widget,
 					 GDK_CROSSING_GTK_GRAB);
     }
@@ -1767,7 +1767,7 @@ gtk_grab_notify_foreach (GtkWidget *child,
     {
       GTK_PRIVATE_UNSET_FLAG (child, GTK_SHADOWED);
       if (was_shadowed && GTK_WIDGET_HAS_POINTER (child)
-	  && GTK_WIDGET_IS_SENSITIVE (child))
+	  && gtk_widget_is_sensitive (child))
 	_gtk_widget_synthesize_crossing (info->old_grab_widget, child,
 					 info->from_grab ? GDK_CROSSING_GTK_GRAB
 					 : GDK_CROSSING_GTK_UNGRAB);
@@ -1827,9 +1827,9 @@ gtk_grab_add (GtkWidget *widget)
   
   g_return_if_fail (widget != NULL);
   
-  if (!GTK_WIDGET_HAS_GRAB (widget) && GTK_WIDGET_IS_SENSITIVE (widget))
+  if (!gtk_widget_has_grab (widget) && gtk_widget_is_sensitive (widget))
     {
-      GTK_WIDGET_SET_FLAGS (widget, GTK_HAS_GRAB);
+      _gtk_widget_set_has_grab (widget, TRUE);
       
       group = gtk_main_get_window_group (widget);
 
@@ -1865,9 +1865,9 @@ gtk_grab_remove (GtkWidget *widget)
   
   g_return_if_fail (widget != NULL);
   
-  if (GTK_WIDGET_HAS_GRAB (widget))
+  if (gtk_widget_has_grab (widget))
     {
-      GTK_WIDGET_UNSET_FLAGS (widget, GTK_HAS_GRAB);
+      _gtk_widget_set_has_grab (widget, FALSE);
 
       group = gtk_main_get_window_group (widget);
       group->grabs = g_slist_remove (group->grabs, widget);
@@ -2404,7 +2404,7 @@ gtk_propagate_event (GtkWidget *widget,
 	  /* If there is a grab within the window, give the grab widget
 	   * a first crack at the key event
 	   */
-	  if (widget != window && GTK_WIDGET_HAS_GRAB (widget))
+	  if (widget != window && gtk_widget_has_grab (widget))
 	    handled_event = gtk_widget_event (widget, event);
 	  
 	  if (!handled_event)
@@ -2412,7 +2412,7 @@ gtk_propagate_event (GtkWidget *widget,
 	      window = gtk_widget_get_toplevel (widget);
 	      if (GTK_IS_WINDOW (window))
 		{
-		  if (GTK_WIDGET_IS_SENSITIVE (window))
+		  if (gtk_widget_is_sensitive (window))
 		    gtk_widget_event (window, event);
 		}
 	    }
@@ -2436,7 +2436,7 @@ gtk_propagate_event (GtkWidget *widget,
 	   * to have children of the viewport eat the scroll
 	   * event
 	   */
-	  if (!GTK_WIDGET_IS_SENSITIVE (widget))
+	  if (!gtk_widget_is_sensitive (widget))
 	    handled_event = event->type != GDK_SCROLL;
 	  else
 	    handled_event = gtk_widget_event (widget, event);
@@ -2555,7 +2555,7 @@ gtk_print (gchar *str)
 				 G_CALLBACK (gtk_widget_hide),
 				 GTK_OBJECT (window));
       gtk_box_pack_start (GTK_BOX (box2), button, TRUE, TRUE, 0);
-      GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+      gtk_widget_set_can_default (button, TRUE);
       gtk_widget_grab_default (button);
       gtk_widget_show (button);
     }
@@ -2564,7 +2564,7 @@ gtk_print (gchar *str)
   gtk_text_insert (GTK_TEXT (text), NULL, NULL, NULL, str, -1);
   level -= 1;
   
-  if (!GTK_WIDGET_VISIBLE (window))
+  if (!gtk_widget_get_visible (window))
     gtk_widget_show (window);
 }
 #endif
