@@ -31,6 +31,25 @@
 #include "gtkprivate.h"
 #include "gtkalias.h"
 
+/**
+ * SECTION:gtkviewport
+ * @Short_description: An adapter which makes widgets scrollable
+ * @Title: GtkViewport
+ * @See_also:#GtkScrolledWindow, #GtkAdjustment
+ *
+ * The #GtkViewport widget acts as an adaptor class, implementing
+ * scrollability for child widgets that lack their own scrolling
+ * capabilities. Use #GtkViewport to scroll child widgets such as
+ * #GtkTable, #GtkBox, and so on.
+ *
+ * If a widget has native scrolling abilities, such as #GtkTextView,
+ * #GtkTreeView or #GtkIconview, it can be added to a #GtkScrolledWindow
+ * with gtk_container_add(). If a widget does not, you must first add the
+ * widget to a #GtkViewport, then add the viewport to the scrolled window.
+ * The convenience function gtk_scrolled_window_add_with_viewport() does
+ * exactly this, so you can ignore the presence of the viewport.
+ */
+
 enum {
   PROP_0,
   PROP_HADJUSTMENT,
@@ -574,6 +593,24 @@ gtk_viewport_get_bin_window (GtkViewport *viewport)
   return viewport->bin_window;
 }
 
+/**
+ * gtk_viewport_get_view_window:
+ * @viewport: a #GtkViewport
+ *
+ * Gets the view window of the #GtkViewport.
+ *
+ * Return value: (transfer none): a #GdkWindow
+ *
+ * Since: 2.22
+ **/
+GdkWindow*
+gtk_viewport_get_view_window (GtkViewport *viewport)
+{
+  g_return_val_if_fail (GTK_IS_VIEWPORT (viewport), NULL);
+
+  return viewport->view_window;
+}
+
 static void
 gtk_viewport_realize (GtkWidget *widget)
 {
